aboutsummaryrefslogtreecommitdiff
path: root/mesonbuild/dependencies/ui.py
diff options
context:
space:
mode:
authorRoman Shpuntov <roman.shpuntov@gmail.com>2019-06-12 18:08:29 +0700
committerJussi Pakkanen <jpakkane@gmail.com>2019-06-13 21:31:03 +0300
commit3b17344b116d13b99b6436f3b9b09ca294079625 (patch)
tree89c36d1946e47e700ce6b43a221f4e38b8aa2ea3 /mesonbuild/dependencies/ui.py
parent4b73f5022262a2c8b2c1a4d234ea64d4714b343d (diff)
downloadmeson-3b17344b116d13b99b6436f3b9b09ca294079625.zip
meson-3b17344b116d13b99b6436f3b9b09ca294079625.tar.gz
meson-3b17344b116d13b99b6436f3b9b09ca294079625.tar.bz2
tvOS: added support AppleTVOS
Diffstat (limited to 'mesonbuild/dependencies/ui.py')
-rw-r--r--mesonbuild/dependencies/ui.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/mesonbuild/dependencies/ui.py b/mesonbuild/dependencies/ui.py
index f96668b..6d784e6 100644
--- a/mesonbuild/dependencies/ui.py
+++ b/mesonbuild/dependencies/ui.py
@@ -372,8 +372,8 @@ class QtBaseDependency(ExternalDependency):
continue
(k, v) = tuple(line.split(':', 1))
qvars[k] = v
- # Qt on macOS uses a framework, but Qt for iOS does not
- if self.env.machines.host.is_darwin() and 'ios' not in qvars['QMAKE_XSPEC']:
+ # Qt on macOS uses a framework, but Qt for iOS/tvOS does not
+ if self.env.machines.host.is_darwin() and 'ios' not in qvars['QMAKE_XSPEC'] and 'tvos' not in qvars['QMAKE_XSPEC']:
mlog.debug("Building for macOS, looking for framework")
self._framework_detect(qvars, mods, kwargs)
return qmake